package imt.concours;

import static imt.concours.ConcoursTest.CHEF_1;
import static imt.concours.ConcoursTest.JURY_1;
import static imt.concours.ConcoursTest.JURY_2;
import static imt.concours.ConcoursTest.JURY_3;
import static imt.concours.ConcoursTest.PROPOSITIONS;
import static imt.concours.ConcoursTest.*;
import static org.assertj.core.api.Assertions.assertThat;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.junit.jupiter.api.Test;

import imt.ingredients.Ingredient;
import imt.ingredients.Plat;
import imt.personnes.Chef;
import imt.personnes.Genre;
import imt.personnes.Specialite;

public class FileConcoursTest {
	@Test
	void fileDeConcours_tout_les_concours_du_chef() {
		Set<Proposition> propositionsSansTelChef = new HashSet<>(PROPOSITIONS);
		propositionsSansTelChef.remove(PROPOSITION_1);
		propositionsSansTelChef.add(
				new Proposition(new Plat(99, "plat99", new Ingredient[] {}), new Chef(99, "nom99", "prenom99", "QSD",
						Genre.HOMME, 4, Specialite.CUISINIER, Set.of(new Plat(99, "plat99", new Ingredient[] {})))));

		Concours concours1 = new Concours(JURY_1, JURY_2, JURY_3, PROPOSITIONS);
		Concours concours2 = new Concours(JURY_1, JURY_2, JURY_3, propositionsSansTelChef);
		Concours concours3 = new Concours(JURY_1, JURY_2, JURY_3, new HashSet<>(PROPOSITIONS));

		FileConcours fileConcours = new FileConcours(concours1, concours2, concours3);

		assertThat(fileConcours.concoursAuquelParticipe(CHEF_1)).isEqualTo(List.of(concours1, concours3));
	}

	@Test
	void concours_termines() {
		Concours concours1 = new Concours(JURY_1, JURY_2, JURY_3, PROPOSITIONS);
		Concours concours2 = new Concours(JURY_1, JURY_2, JURY_3, PROPOSITIONS);
		Concours concours3 = new Concours(JURY_1, JURY_2, JURY_3, PROPOSITIONS);

		FileConcours fileConcours = new FileConcours(concours1, concours2, concours3);
		assertThat(fileConcours.passerAuConcoursSuivant()).isFalse();
		forcer_la_fin_du_concours(concours1);
		
		assertThat(fileConcours.passerAuConcoursSuivant()).isTrue();

		assertThat(fileConcours.concoursTermines()).isEqualTo(List.of(concours1));
	}

	void forcer_la_fin_du_concours(Concours concours) {
		assertThat(concours.estTermine()).isFalse();
		concours.noter(PROPOSITION_1, 10);
		concours.noter(PROPOSITION_2, 20);
		concours.noter(PROPOSITION_3, 30);
		concours.noter(PROPOSITION_4, 40);
		concours.noter(PROPOSITION_5, 50);
		assertThat(concours.estTermine()).isTrue();
	}

	@Test
	void concours_auquel_un_chef_a_participe() {

	}
}
